# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: highdim.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='highdim.proto',
  package='highdim',
  syntax='proto2',
  serialized_pb=_b('\n\rhighdim.proto\x12\x07highdim\"W\n\rHighDimHeader\x12\x1d\n\x05\x61ssay\x18\x01 \x03(\x0b\x32\x0e.highdim.Assay\x12\'\n\ncolumnSpec\x18\x02 \x03(\x0b\x32\x13.highdim.ColumnSpec\"n\n\nColumnSpec\x12\x0c\n\x04name\x18\x01 \x02(\t\x12,\n\x04type\x18\x02 \x02(\x0e\x32\x1e.highdim.ColumnSpec.ColumnType\"$\n\nColumnType\x12\n\n\x06\x44OUBLE\x10\x01\x12\n\n\x06STRING\x10\x02\"\x98\x01\n\x05\x41ssay\x12\x0f\n\x07\x61ssayId\x18\x01 \x02(\x03\x12\x11\n\tpatientId\x18\x02 \x02(\t\x12\x16\n\x0esampleTypeName\x18\x03 \x01(\t\x12\x15\n\rtimepointName\x18\x04 \x01(\t\x12\x16\n\x0etissueTypeName\x18\x05 \x01(\t\x12\x10\n\x08platform\x18\x06 \x01(\t\x12\x12\n\nsampleCode\x18\x07 \x01(\t\"L\n\x03Row\x12\r\n\x05label\x18\x01 \x02(\t\x12\x11\n\tbioMarker\x18\x02 \x01(\t\x12#\n\x05value\x18\x03 \x03(\x0b\x32\x14.highdim.ColumnValue\";\n\x0b\x43olumnValue\x12\x17\n\x0b\x64oubleValue\x18\x01 \x03(\x01\x42\x02\x10\x01\x12\x13\n\x0bstringValue\x18\x02 \x03(\tB3\n\"org.transmartproject.rest.protobufB\rHighDimProtos')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_COLUMNSPEC_COLUMNTYPE = _descriptor.EnumDescriptor(
  name='ColumnType',
  full_name='highdim.ColumnSpec.ColumnType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=189,
  serialized_end=225,
)
_sym_db.RegisterEnumDescriptor(_COLUMNSPEC_COLUMNTYPE)


_HIGHDIMHEADER = _descriptor.Descriptor(
  name='HighDimHeader',
  full_name='highdim.HighDimHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='assay', full_name='highdim.HighDimHeader.assay', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='columnSpec', full_name='highdim.HighDimHeader.columnSpec', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=113,
)


_COLUMNSPEC = _descriptor.Descriptor(
  name='ColumnSpec',
  full_name='highdim.ColumnSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='highdim.ColumnSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='highdim.ColumnSpec.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COLUMNSPEC_COLUMNTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=225,
)


_ASSAY = _descriptor.Descriptor(
  name='Assay',
  full_name='highdim.Assay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='assayId', full_name='highdim.Assay.assayId', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='patientId', full_name='highdim.Assay.patientId', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sampleTypeName', full_name='highdim.Assay.sampleTypeName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timepointName', full_name='highdim.Assay.timepointName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tissueTypeName', full_name='highdim.Assay.tissueTypeName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform', full_name='highdim.Assay.platform', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sampleCode', full_name='highdim.Assay.sampleCode', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=380,
)


_ROW = _descriptor.Descriptor(
  name='Row',
  full_name='highdim.Row',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='highdim.Row.label', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bioMarker', full_name='highdim.Row.bioMarker', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='highdim.Row.value', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=458,
)


_COLUMNVALUE = _descriptor.Descriptor(
  name='ColumnValue',
  full_name='highdim.ColumnValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='doubleValue', full_name='highdim.ColumnValue.doubleValue', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))),
    _descriptor.FieldDescriptor(
      name='stringValue', full_name='highdim.ColumnValue.stringValue', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=519,
)

_HIGHDIMHEADER.fields_by_name['assay'].message_type = _ASSAY
_HIGHDIMHEADER.fields_by_name['columnSpec'].message_type = _COLUMNSPEC
_COLUMNSPEC.fields_by_name['type'].enum_type = _COLUMNSPEC_COLUMNTYPE
_COLUMNSPEC_COLUMNTYPE.containing_type = _COLUMNSPEC
_ROW.fields_by_name['value'].message_type = _COLUMNVALUE
DESCRIPTOR.message_types_by_name['HighDimHeader'] = _HIGHDIMHEADER
DESCRIPTOR.message_types_by_name['ColumnSpec'] = _COLUMNSPEC
DESCRIPTOR.message_types_by_name['Assay'] = _ASSAY
DESCRIPTOR.message_types_by_name['Row'] = _ROW
DESCRIPTOR.message_types_by_name['ColumnValue'] = _COLUMNVALUE

HighDimHeader = _reflection.GeneratedProtocolMessageType('HighDimHeader', (_message.Message,), dict(
  DESCRIPTOR = _HIGHDIMHEADER,
  __module__ = 'highdim_pb2'
  # @@protoc_insertion_point(class_scope:highdim.HighDimHeader)
  ))
_sym_db.RegisterMessage(HighDimHeader)

ColumnSpec = _reflection.GeneratedProtocolMessageType('ColumnSpec', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNSPEC,
  __module__ = 'highdim_pb2'
  # @@protoc_insertion_point(class_scope:highdim.ColumnSpec)
  ))
_sym_db.RegisterMessage(ColumnSpec)

Assay = _reflection.GeneratedProtocolMessageType('Assay', (_message.Message,), dict(
  DESCRIPTOR = _ASSAY,
  __module__ = 'highdim_pb2'
  # @@protoc_insertion_point(class_scope:highdim.Assay)
  ))
_sym_db.RegisterMessage(Assay)

Row = _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), dict(
  DESCRIPTOR = _ROW,
  __module__ = 'highdim_pb2'
  # @@protoc_insertion_point(class_scope:highdim.Row)
  ))
_sym_db.RegisterMessage(Row)

ColumnValue = _reflection.GeneratedProtocolMessageType('ColumnValue', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNVALUE,
  __module__ = 'highdim_pb2'
  # @@protoc_insertion_point(class_scope:highdim.ColumnValue)
  ))
_sym_db.RegisterMessage(ColumnValue)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"org.transmartproject.rest.protobufB\rHighDimProtos'))
_COLUMNVALUE.fields_by_name['doubleValue'].has_options = True
_COLUMNVALUE.fields_by_name['doubleValue']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
# @@protoc_insertion_point(module_scope)
